@@ -17,7 +17,7 @@ def build_table(n, selected_operation, headers=False, inversibles=False):
     if selected_operation in ["sum", "prod"]:
         operation = class_sum if selected_operation == 'sum' else class_prod
         
-        integer_set = list(get_inversibles(n)) if inversibles else set(range(n))
+        integer_set = list(get_inversibles(n)) if inversibles else list(range(n))
 
         if headers:
                 table = [['+' if selected_operation == 'sum' else '*'] + integer_set]
@@ -32,4 +32,4 @@ def build_table(n, selected_operation, headers=False, inversibles=False):
 
         return table
     else:
-        raise ValueError("Please pass a valid operation ('sum' or 'prod') as second argument.")
\ No newline at end of file
+        raise ValueError("Please pass a valid operation ('sum' or 'prod') as second argument.")
